%global glib2_version %(pkg-config --modversion glib-2.0 2>/dev/null || echo bad)
%global qmi_version %(pkg-config --modversion qmi-glib 2>/dev/null || echo bad)
%global mbim_version %(pkg-config --modversion mbim-glib 2>/dev/null || echo bad)

Name: ModemManager
Version: 1.18.6
Release: 3%{?dist}
Summary: Mobile broadband modem management service
License: GPL-2.0+
URL: http://www.freedesktop.org/wiki/Software/ModemManager/
Source0: https://www.freedesktop.org/software/ModemManager/%{name}-%{version}.tar.xz

# For mbim-proxy and qmi-proxy
Requires: libmbim-utils
Requires: libqmi-utils
Requires: %{name}-glib%{?_isa} = %{version}-%{release}

# Don't allow older versions of these than what we built against,
# because they add new API w/o versioning it or bumping the SONAME
Conflicts: glib2%{?_isa} < %{glib2_version}
Conflicts: libqmi%{?_isa} < %{qmi_version}
Conflicts: libmbim%{?_isa} < %{mbim_version}

Requires(post): systemd
Requires(postun): systemd
Requires(preun): systemd

Requires: polkit

BuildRequires: automake autoconf libtool autoconf-archive
BuildRequires: dbus
BuildRequires: dbus-daemon
BuildRequires: gettext-devel >= 0.19.8
BuildRequires: glib2-devel >= 2.56
BuildRequires: gobject-introspection-devel >= 1.38
BuildRequires: gtk-doc
BuildRequires: libgudev1-devel >= 232
BuildRequires: libmbim-devel >= 1.26.0
BuildRequires: libqmi-devel >= 1.30.0
BuildRequires: libqrtr-glib-devel >= 1.0.0
BuildRequires: make
BuildRequires: systemd-devel >= 209
BuildRequires: vala
BuildRequires: polkit-devel
BuildRequires: python3-gobject
BuildRequires: python3-dbus

%global __provides_exclude ^libmm-plugin-

%description
The ModemManager service manages WWAN modems and provides a consistent API for
interacting with these devices to client applications.

%package devel
Summary: Libraries and headers for adding ModemManager support to applications
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: pkgconfig

%description devel
This package contains various headers for accessing some ModemManager functionality
from applications.

%package glib
Summary: Libraries for adding ModemManager support to applications that use glib.
Requires: glib2 >= %{glib2_version}

%description glib
This package contains the libraries that make it easier to use some ModemManager
functionality from applications that use glib.

%package glib-devel
Summary: Libraries and headers for adding ModemManager support to applications that use glib.
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: %{name}-devel%{?_isa} = %{version}-%{release}
Requires: %{name}-glib%{?_isa} = %{version}-%{release}
Requires: glib2-devel >= %{glib2_version}
Requires: pkgconfig

%description glib-devel
This package contains various headers for accessing some ModemManager functionality
from glib applications.

%package vala
Summary: Vala bindings for ModemManager
Requires: vala
Requires: %{name}-glib%{?_isa} = %{version}-%{release}

%description vala
Vala bindings for ModemManager

%prep
%autosetup -p1

%build
# Regenerate configure, because the one that is shipped
# doesn't seem to obey --disable-rpath for reasons unknown.
autoreconf -vif
%configure \
	--disable-rpath \
	--disable-silent-rules \
	--with-systemd-suspend-resume \
	--with-systemd-journal \
	--enable-more-warnings=no \
	--with-udev-base-dir=%{_prefix}/lib/udev \
	--enable-gtk-doc \
	--with-qmi=yes \
	--with-mbim=yes \
%ifarch aarch64
	--enable-plugin-qcom-soc \
%endif
	--disable-static \
	--with-polkit=permissive \
	--with-dist-version=%{version}-%{release}

%make_build

%check
make check

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete

%find_lang %{name}

%ldconfig_scriptlets glib

%post
%systemd_post ModemManager.service

%preun
%systemd_preun ModemManager.service

%postun
%systemd_postun ModemManager.service

%files -f %{name}.lang
%license COPYING
%doc README
%{_sysconfdir}/dbus-1/system.d/org.freedesktop.ModemManager1.conf
%{_datadir}/dbus-1/system-services/org.freedesktop.ModemManager1.service
%attr(0755,root,root) %{_sbindir}/ModemManager
%attr(0755,root,root) %{_bindir}/mmcli
%dir %{_libdir}/%{name}
%attr(0755,root,root) %{_libdir}/%{name}/*.so*
%{_udevrulesdir}/*
%{_datadir}/polkit-1/actions/*.policy
%{_unitdir}/ModemManager.service
%{_datadir}/icons/hicolor/22x22/apps/*.png
%{_datadir}/bash-completion
%{_datadir}/ModemManager
%{_mandir}/man1/*
%{_mandir}/man8/*

%files devel
%{_includedir}/ModemManager/
%dir %{_datadir}/gtk-doc/html/%{name}
%{_datadir}/gtk-doc/html/%{name}/*
%{_libdir}/pkgconfig/%{name}.pc
%{_datadir}/dbus-1/interfaces/*.xml

%files glib
%license COPYING
%{_libdir}/libmm-glib.so.*
%{_libdir}/girepository-1.0/*.typelib

%files glib-devel
%{_libdir}/libmm-glib.so
%dir %{_includedir}/libmm-glib
%{_includedir}/libmm-glib/*.h
%{_libdir}/pkgconfig/mm-glib.pc
%dir %{_datadir}/gtk-doc/html/libmm-glib
%{_datadir}/gtk-doc/html/libmm-glib/*
%{_datadir}/gir-1.0/*.gir

%files vala
%{_datadir}/vala/vapi/libmm-glib.*

%changelog
* Tue Mar 15 2022 Yaobin Shi <shiyaobin.syb@alibaba-inc.com> - 1.18.6-3
- Add BuildRequires python3-gobject and python3-dbus

* Mon Mar 14 2022 Yaobin Shi <shiyaobin.syb@alibaba-inc.com> - 1.18.6-2
- enable make check for Anolis OS 23

* Thu Mar 10 2022 Larry Shi <larryshi@openanolis.org> - 1.18.6-1
- Init for Anolis OS 23
